#include <stdio.h>
#include <math.h>

#define Pi 3.14159265358979323846

// Converts parallax, right ascension, and declination of star
// 		to stellar coordinates ( x, y, z ) in parsecs
// Can be used to add more stars to stars.dat by hand

main ( int argc, char *argv[] )
{
	if( argc != 6 )
	{
		printf( "Format: where parallax RAhours RAminutes DECdegrees DECminutes\n" );
		return 0;
	}
	double parallax, aHours, aMinutes;
	double dDegrees, dMinutes;
	
	double R, RA, DEC;
	double x, y, z;
	
	sscanf( argv[1], "%le", &parallax );
	sscanf( argv[2], "%le", &aHours );
	sscanf( argv[3], "%le", &aMinutes );
	sscanf( argv[4], "%le", &dDegrees );
	sscanf( argv[5], "%le", &dMinutes );
	
	if( dDegrees < 0 )
		dMinutes *= -1;
	
	R = 1/parallax; // R is distance of star in parsecs ( 1 parsec = 3.26 lightyears )
	RA = 2*Pi*( (aHours/24) + (aMinutes/(24*60)) ); // hours, minutes to radians
	DEC = 2*Pi*( (dDegrees/360) + (dMinutes/(360*60)) ); // degrees, minutes to radians
	
	x = R*cos(DEC)*cos(RA);
	y = R*cos(DEC)*sin(RA);
	z = R*sin(DEC);
	
	printf( "Right Ascension: %f radians\n", RA );
	printf( "Declination: %f radians\n", DEC );
	printf( "Distance: %f parsecs ( %f light-years )\n", R, R * 3.26 );
	printf( "x,y,z: %f %f %f\n", x, y, z );
	return 0;
}